@@ -13,7 +13,7 @@ use IO::File;
 use Module::Pluggable ( search_path => 'Template::Benchmark::Engines',
                         sub_name    => 'engine_plugins' );
 
-our $VERSION = '0.99_11';
+our $VERSION = '0.99_12';
 
 my @valid_features = qw/
     literal_text
@@ -118,7 +118,8 @@ my $var_hash1 = {
         },
     array_variable   => [ qw/I have an imagination honest/ ],
     this => { is => { a => { very => { deep => { hash => {
-        structure => "My god, it's full of hashes.",
+        #  No longer "it's", to avoid HTML-escaping trap with some engines.
+        structure => "My god, it be full of hashes.",
         } } } } } },
     template_if_true  => 'True dat',
     template_if_false => 'Nay, Mister Wilks',
@@ -192,19 +193,30 @@ sub new
         unless scalar( keys( %{$options->{ only_plugin }} ) );
     delete $options->{ skip_plugin }
         unless scalar( keys( %{$options->{ skip_plugin }} ) );
+    delete $options->{ features_from }
+        unless $options->{ features_from };
+    delete $options->{ cache_types_from }
+        unless $options->{ cache_types_from };
 
     $self->{ engines } = [];
     $self->{ engine_errors } = {};
     foreach my $plugin ( $self->engine_plugins() )
     {
         my $leaf = _engine_leaf( $plugin );
-        if( $options->{ only_plugin } )
+
+        #  Force-require any features_from or cache_types_from plugin,
+        #  regardless of their only_plugin or skip_plugin settings.
+        if( ( ( $options->{ features_from }    || '' ) ne $leaf ) and
+            ( ( $options->{ cache_types_from } || '' ) ne $leaf ) )
         {
-            next unless $options->{ only_plugin }->{ $leaf };
-        }
-        if( $options->{ skip_plugin } )
-        {
-            next if $options->{ skip_plugin }->{ $leaf };
+            if( $options->{ only_plugin } )
+            {
+                next unless $options->{ only_plugin }->{ $leaf };
+            }
+            if( $options->{ skip_plugin } )
+            {
+                next if $options->{ skip_plugin }->{ $leaf };
+            }
         }
         eval "use $plugin";
         if( $@ )
@@ -213,7 +225,14 @@ sub new
         }
         else
         {
-            push @{$self->{ engines }}, $plugin;
+            if( ( $options->{ features_from } || '' ) eq $leaf )
+            {
+                unshift @{$self->{ engines }}, $plugin;
+            }
+            else
+            {
+                push @{$self->{ engines }}, $plugin;
+            }
         }
     }
 
@@ -223,8 +242,15 @@ sub new
     mkpath( $self->{ template_dir } );
     mkpath( $self->{ cache_dir } );
 
-    $self->{ cache_types } =
-        [ grep { $options->{ $_ } } @valid_cache_types ];
+    if( $options->{ cache_types_from } )
+    {
+        $self->{ cache_types } = [ @valid_cache_types ];
+    }
+    else
+    {
+        $self->{ cache_types } =
+            [ grep { $options->{ $_ } } @valid_cache_types ];
+    }
     #  TODO: sanity-check some are left.
 
     $self->{ features } =
@@ -277,12 +303,24 @@ sub new
             $benchmark_functions{ $cache_type } = $functions;
         }
 
+        $self->{ cache_types } = [
+            grep { $benchmark_functions{ $_ } } @valid_cache_types
+            ]
+            if ( ( $options->{ cache_types_from } || '' ) eq $leaf );
+
         unless( %benchmark_functions )
         {
             $self->engine_error( $leaf, 'No matching benchmark functions.' );
             next ENGINE;
         }
 
+        $self->{ features } = [ @valid_features ]
+            if ( ( $options->{ features_from } || '' ) eq $leaf );
+
+#print "Looking at $leaf.\n";
+#use Data::Dumper;
+#print "  features: " . Data::Dumper::Dumper( $self->{ features } ) . "\n";
+
         $template = '';
         $missing_syntaxes = '';
         foreach my $feature ( @{$self->{ features }} )
@@ -300,6 +338,15 @@ sub new
             }
         }
 
+        if( ( ( $options->{ features_from } || '' ) eq $leaf ) and
+            $missing_syntaxes )
+        {
+            my %missing = map { $_ => 1 } split( /\s+/, $missing_syntaxes );
+            $self->{ features } =
+                [ grep { !$missing{ $_ } } @{$self->{ features }} ];
+            $missing_syntaxes = '';
+        }
+
         if( $missing_syntaxes )
         {
             $self->engine_error( $leaf,
@@ -359,6 +406,19 @@ sub new
         }
     }
 
+    if( $options->{ cache_types_from } )
+    {
+        my %needed_types = map { $_ => 1 } @{$self->{ cache_types }};
+
+        #  We need to delete any benchmark functions that crept in
+        #  before we figured out what cache types we needed.
+        $self->{ benchmark_functions } = {
+            map { $_ => $self->{ benchmark_functions }->{ $_ } }
+            grep { $needed_types{ $_ } }
+            keys( %{$self->{ benchmark_functions }} )
+            };
+    }
+
     #  Strip any cache types that ended up with no functions.
     $self->{ cache_types } = [
         grep { $self->{ benchmark_functions }->{ $_ } }
@@ -636,6 +696,10 @@ performance of template modules that support expression parsing when running
 with a shared memory cache?  Do you even know which ones I<allow> you to do
 that?  This module lets you find that sort of thing out.
 
+As of current writing, there are plugins to let you compare the performance
+and features of 21 different perl template engines in a total of 75 different
+configurations.
+
 If you're just after results, then you should probably start with the
 L<benchmark_template_engines> script first, it provides a commandline
 UI onto L<Template::Benchmark> and gives you human-readable reports
@@ -656,7 +720,7 @@ L<HTML::Template>, L<Template::Sandbox> and so on.
 
 =head2 Cache Types
 
-I<cache types> determine the source of the template and the caching
+I<Cache types> determine the source of the template and the caching
 mechanic applied, currently there are the following I<cache types>:
 I<uncached_string>, I<uncached_disk>, I<disk_cache>, I<shared_memory_cache>,
 I<memory_cache> and I<instance_reuse>.
@@ -679,7 +743,7 @@ consult the L<Template::Benchmark::Engine> documentation.
 =head2 Benchmark Functions
 
 Each I<template engine> plugin provides the means to produce a
-I<benchmark function> for each I<cache types>.
+I<benchmark function> for each I<cache type>.
 
 The I<benchmark function> is an anonymous sub that is expected
 to be passed the template, and two hashrefs of template variables,
@@ -845,6 +909,26 @@ Each of these options sets the corresponding I<template feature> on
 or off.  At least one of these must be true for any benchmarks to
 run.
 
+=item B<features_from> => I<$plugin> (default none)
+
+If set, then the list of I<template features> will be drawn
+from those supported by the given plugin.
+
+If this option is set, any I<template features> you supply
+as options will be ignored and overwritten, and the plugin
+named will also be benchmarked even if you attempted to
+exclude it with the C<skip_plugin> or C<only_plugin> options.
+
+=item B<cache_types_from> => I<$plugin> (default none)
+
+If set, then the list of I<cache types> will be drawn
+from those supported by the given plugin.
+
+If this option is set, any I<cache types> you supply
+as options will be ignored and overwritten, and the plugin
+named will also be benchmarked even if you attempted to
+exclude it with the C<skip_plugin> or C<only_plugin> options.
+
 =item B<template_repeats> => I<$number> (default 30)
 
 After the template is constructed from the various feature snippets
@@ -971,14 +1055,14 @@ does in fact.
 Returns a list of the valid I<cache types>.
 This can be used to keep external programs up-to-date
 with what I<cache types> are available in case new ones are added.
-This is what L<benchmark_template_engines> does in fact.
+L<benchmark_template_engines> does just that.
 
 =item I<@features> = B<< Template::Benchmark->valid_features() >>
 
 Returns a list of the valid I<template features>.
 This can be used to keep external programs up-to-date
 with what I<template features> are available in case new ones are added.
-This is what L<benchmark_template_engines> does in fact.
+This is how L<benchmark_template_engines> gets at this info too.
 
 =item B<< $errors = $benchmark->engine_errors() >>
 
@@ -991,7 +1075,7 @@ the I<engine> didn't support.
 =item B<< $benchmark->engine_error( >> I<$engine>, I<$error_message> B<)>
 
 Pushes I<$error_message> onto the list of error messages for the
-engine plugin I<$engine>..
+engine plugin I<$engine>.
 
 =item I<$number> = B<< $benchmark->number_of_benchmarks() >>
 
@@ -1057,19 +1141,19 @@ will be the following additional information:
           },
       reference    =>
           {
-              type => 'uncached_string',
+              type   => 'uncached_string',
               tag    => 'TS',
               output => template output,
           },
       benchmarks   =>
           [
               {
-                 type     => 'uncached_string',
+                 type       => 'uncached_string',
                  timings    => Benchmark::timethese() results,
                  comparison => Benchmark::cmpthese() results,
               },
               {
-                 type     => 'memory_cache',
+                 type       => 'memory_cache',
                  timings    => Benchmark::timethese() results,
                  comparison => Benchmark::cmpthese() results,
               },
@@ -1266,11 +1350,27 @@ used.
 This would be helpful for anything wishing to archive benchmark
 results, since it may (will!) influence how comparable results are.
 
+=item Engine meta-data not retrievable if template engine isn't installed
+
+The I<template engine> plugins are designed in a way that requires their
+respective I<template engine> to be installed for the plugin to compile
+successfully: this allows the benchmarked code in the plugin to be free
+of cruft testing for module availability, which in turn gives it a more
+accurate benchmark.
+
+The downside of this approach is that none of the meta-information like
+syntaxes, engine descriptions, syntax type, and "pure-perl"ness is
+available unless the I<template engine> is available.
+
+This is potentially sucky, but on the other hand it's probably an indication
+that the meta-information ought to belong elsewhere, probably in a different
+distribution entirely as it's not specifically to do with benchmarking.
+
 =back
 
 =head1 AUTHOR
 
-Sam Graham, C<< <libtemplate-benchmark-perl at illusori.co.uk> >>
+Sam Graham, C<< <libtemplate-benchmark-perl BLAHBLAH illusori.co.uk> >>
 
 =head1 BUGS
 
