@@ -11,16 +11,11 @@ use HTML::Template;
 use HTML::Template::Expr;
 use HTML::Template::Pro;
 
-our $VERSION = '0.99_11';
+our $VERSION = '0.99_12';
 
 our %feature_syntaxes = (
-    literal_text              => <<END_OF_TEMPLATE,
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-END_OF_TEMPLATE
+    literal_text              =>
+        join( "\n", ( join( ' ', ( 'foo' ) x 12 ) ) x 5 ),
     scalar_variable           =>
         '<TMPL_VAR NAME=scalar_variable>',
     hash_variable_value       =>
@@ -76,6 +71,9 @@ END_OF_TEMPLATE
         '<TMPL_VAR EXPR="substr( variable_function_arg, 4, 2 )">',
     );
 
+sub syntax_type { return( 'mini-language' ); }
+sub pure_perl { return( 0 ); }
+
 sub benchmark_descriptions
 {
     return( {
