@@ -12,16 +12,11 @@ use Cache::CacheFactory;
 use Cache::FastMmap;
 use CHI;
 
-our $VERSION = '0.99_11';
+our $VERSION = '0.99_12';
 
 our %feature_syntaxes = (
-    literal_text              => <<END_OF_TEMPLATE,
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-END_OF_TEMPLATE
+    literal_text              =>
+        join( "\n", ( join( ' ', ( 'foo' ) x 12 ) ) x 5 ),
     scalar_variable           =>
         '<: expr scalar_variable :>',
     hash_variable_value       =>
@@ -78,6 +73,9 @@ END_OF_TEMPLATE
         '<: expr substr( variable_function_arg, 4, 2 ) :>',
     );
 
+sub syntax_type { return( 'mini-language' ); }
+sub pure_perl { return( 1 ); }
+
 sub benchmark_descriptions
 {
     return( {
