@@ -7,16 +7,11 @@ use base qw/Template::Benchmark::Engine/;
 
 use Text::ClearSilver;
 
-our $VERSION = '0.99_11';
+our $VERSION = '0.99_12';
 
 our %feature_syntaxes = (
-    literal_text              => <<END_OF_TEMPLATE,
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-END_OF_TEMPLATE
+    literal_text              =>
+        join( "\n", ( join( ' ', ( 'foo' ) x 12 ) ) x 5 ),
     scalar_variable           =>
         '<?cs var:scalar_variable ?>',
     hash_variable_value       =>
@@ -77,6 +72,9 @@ END_OF_TEMPLATE
         '<?cs var:string.slice( variable_function_arg, 4, 6 ) ?>',
     );
 
+sub syntax_type { return( 'mini-language' ); }
+sub pure_perl { return( 0 ); }
+
 sub benchmark_descriptions
 {
     return( {
