@@ -9,16 +9,11 @@ use Text::MicroMason;
 
 use File::Spec;
 
-our $VERSION = '0.99_11';
+our $VERSION = '0.99_12';
 
 our %feature_syntaxes = (
-    literal_text              => <<END_OF_TEMPLATE,
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-END_OF_TEMPLATE
+    literal_text              =>
+        join( "\n", ( join( ' ', ( 'foo' ) x 12 ) ) x 5 ),
     scalar_variable           =>
         '<% $ARGS{scalar_variable} %>',
     hash_variable_value       =>
@@ -85,6 +80,9 @@ END_OF_TEMPLATE
         '<% substr( $ARGS{variable_function_arg}, 4, 2 ) %>',
     );
 
+sub syntax_type { return( 'embedded-perl' ); }
+sub pure_perl { return( 1 ); }
+
 sub benchmark_descriptions
 {
     return( {
@@ -173,7 +171,7 @@ __END__
 
 =head1 NAME
 
-Template::Benchmark::Engines::TextMicroMasonHM - Template::Benchmark plugin for Text::MicroMason.
+Template::Benchmark::Engines::TextMicroMasonHM - Template::Benchmark plugin for Text::MicroMason in HTML:Mason mode.
 
 =head1 SYNOPSIS
 
