@@ -9,16 +9,11 @@ use Text::Tmpl;
 
 use File::Spec;
 
-our $VERSION = '0.99_11';
+our $VERSION = '0.99_12';
 
 our %feature_syntaxes = (
-    literal_text              => <<END_OF_TEMPLATE,
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-foo foo foo foo foo foo foo foo foo foo foo foo
-END_OF_TEMPLATE
+    literal_text              =>
+        join( "\n", ( join( ' ', ( 'foo' ) x 12 ) ) x 5 ),
     scalar_variable           =>
         '<!-- echo $scalar_variable -->',
     hash_variable_value       =>
@@ -75,6 +70,9 @@ END_OF_TEMPLATE
         undef,
     );
 
+sub syntax_type { return( 'mini-language' ); }
+sub pure_perl { return( 0 ); }
+
 sub benchmark_descriptions
 {
     return( {
